========
*pytags*
========

.. image:: https://img.shields.io/pypi/v/pytags

.. image:: https://img.shields.io/github/license/veltzer/pytags

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pytags

author: Mark Veltzer

version: 0.0.11


